==> nextcloud-22.2.3p0.tgz: nextcloud/apps/support/l10n/is.js <==
OC.L10N.register(
    "support",
    {
    "Link:" : "Tengill:",
    "Password:" : "Lykilorð:",
    "Generating system report failed." : "Gerð kerfisskýrslu mistókst.",
    "Subscription notifications" : "Tilkynningar um áskriftir",
    "Could not share file \"%s\"." : "Gat ekki deilt skránni \"%s\".",
    "Nextcloud Subscription" : "Nextcloud áskrift",
    "Your server has no Nextcloud Subscription or your Subscription has expired." : "Þjónninn þinn er ekki með neina Nextcloud-áskrift eða að áskriftin þín er útrunnin.",
    "Your Nextcloud Subscription has expired!" : "Nextcloud áskriftin þín er útrunnin!",
    "Your server has no Nextcloud Subscription" : "Þjónninn þinn er ekki með neina Nextcloud-áskrift",
    "Learn more now" : "Læra meira núna",
    "Dear admin," : "Kæri stjórnandi,",
    "Thank you," : "Bestu þakkir,",
    "Your Nextcloud team" : "Nextcloud teymið þitt",
    "Support" : "Aðstoð",
    "Getting support and help for your Nextcloud" : "Fáðu stuðning og hjálp fyrir Nextcloud-skýið þitt",
    "Basic subscription" : "Einföld áskrift",
    "Standard subscription" : "Venjuleg áskrift",
    "Subscription" : "Áskrift",
    "Valid subscription" : "Gild áskrift",
    "Expired subscription" : "Útrunnin áskrift",
    "Subscription key:" : "Áskriftarlykill:",
    "_Expires in %n year_::_Expires in %n years_" : ["Rennur út eftir %n ár","Rennur út eftir %n ár"],
    "_Expires in %n month_::_Expires in %n months_" : ["Rennur út eftir %n mánuð","Rennur út eftir %n mánuði"],
    "_Expires in %n week_::_Expires in %n weeks_" : ["Rennur út eftir %n viku","Rennur út eftir %n vikur"],
    "_Expires in %n day_::_Expires in %n days_" : ["Rennur út eftir %n dag","Rennur út eftir %n daga"],
    "_For %n users_::_For %n users_" : ["Fyrir %n notanda","Fyrir %n notendur"],
    "_currently at %n user_::_currently at %n users_" : ["núna með %n notanda","núna með %n notendur"],
    "Includes support for %s" : "Innifelur aðstoð fyrir %s",
    "Includes support for %1$s & %2$s" : "Innifelur aðstoð fyrir %1$s & %2$s",
    "Includes support for %1$s, %2$s & %3$s" : "Innifelur aðstoð fyrir %1$s, %2$s & %3$s",
    "Update subscription key" : "Uppfæra áskriftarlykil",
    "System information" : "Kerfisupplýsingar",
    "Generate system report" : "Útbúa kerfisskýrslu",
    "Unsupported" : "Óstutt",
    "Advantages" : "Kostir",
    "Get a quote" : "Fáðu tilboð",
    "More information" : "Nánari upplýsingar",
    "Pricing" : "Verðskrá",
    "Commmunity support" : "Stuðningur frá samfélaginu",
    "Forum" : "Vefspjall",
    "GitHub" : "GitHub",
    "Chat" : "Spjall",
    "Chat with us on our IRC channel #nextcloud on Freenode." : "Spjallaðu við okkur á IRC-rásinni #nextcloud á Freenode.",
    "Nextcloud forum" : "Nextcloud spjallsvæði",
    "Nextcloud at GitHub" : "Nextcloud á GitHub",
    "Open chat" : "Opna spjall",
    "Subscription key" : "Áskriftarlykill",
    "The subscription key was invalid." : "Áskriftarlykillinn er ógildur.",
    "News" : "Fréttir",
    "Like our Facebook page" : "Líkaðu við Facebook-síðuna okkar",
    "Follow us on Twitter" : "Fylgstu með okkur á Twitter",
    "Check out our blog" : "Kíktu á bloggið okkar",
    "Subscribe to our newsletter" : "Gerstu áskrifandi að fréttabréfinu okkar"
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");

==> nextcloud-31.0.9.tgz: nextcloud/apps/support/l10n/is.js <==
OC.L10N.register(
    "support",
    {
    "Link:" : "Tengill:",
    "Password:" : "Lykilorð:",
    "Generating system report failed." : "Gerð kerfisskýrslu mistókst.",
    "Subscription notifications" : "Tilkynningar um áskriftir",
    "Nextcloud Subscription" : "Nextcloud áskrift",
    "Your server has no Nextcloud Subscription or your Subscription has expired." : "Þjónninn þinn er ekki með neina Nextcloud-áskrift eða að áskriftin þín er útrunnin.",
    "Your Nextcloud Subscription has expired!" : "Nextcloud áskriftin þín er útrunnin!",
    "Your server has no Nextcloud Subscription" : "Þjónninn þinn er ekki með neina Nextcloud-áskrift",
    "Learn more now" : "Læra meira núna",
    "Dear admin," : "Kæri stjórnandi,",
    "Thank you," : "Bestu þakkir,",
    "Your Nextcloud team" : "Nextcloud teymið þitt",
    "Support" : "Aðstoð",
    "Getting support and help for your Nextcloud" : "Fáðu stuðning og hjálp fyrir Nextcloud-skýið þitt",
    "Basic subscription" : "Einföld áskrift",
    "Standard subscription" : "Venjuleg áskrift",
    "Subscription" : "Áskrift",
    "Valid subscription" : "Gild áskrift",
    "Expired subscription" : "Útrunnin áskrift",
    "Subscription key:" : "Áskriftarlykill:",
    "_For %n users_::_For %n users_" : ["Fyrir %n notanda","Fyrir %n notendur"],
    "_currently at %n user_::_currently at %n users_" : ["núna með %n notanda","núna með %n notendur"],
    "Includes support for %s" : "Innifelur aðstoð fyrir %s",
    "Includes support for %1$s & %2$s" : "Innifelur aðstoð fyrir %1$s & %2$s",
    "Includes support for %1$s, %2$s & %3$s" : "Innifelur aðstoð fyrir %1$s, %2$s & %3$s",
    "Update subscription key" : "Uppfæra áskriftarlykil",
    "System information" : "Kerfisupplýsingar",
    "Generate system report" : "Útbúa kerfisskýrslu",
    "Unsupported" : "Óstutt",
    "Advantages" : "Kostir",
    "Get a quote" : "Fáðu tilboð",
    "More information" : "Nánari upplýsingar",
    "Pricing" : "Verðskrá",
    "Forum" : "Vefspjall",
    "Nextcloud forum" : "Nextcloud spjallsvæði",
    "GitHub" : "GitHub",
    "Nextcloud at GitHub" : "Nextcloud á GitHub",
    "Subscription key" : "Áskriftarlykill",
    "Set subscription key" : "Setja áskriftarlykil",
    "The subscription key was invalid." : "Áskriftarlykillinn er ógildur.",
    "News" : "Fréttir",
    "Like our Facebook page" : "Líkaðu við Facebook-síðuna okkar",
    "Follow us on Twitter" : "Fylgstu með okkur á Twitter",
    "Check out our blog" : "Kíktu á bloggið okkar",
    "Subscribe to our newsletter" : "Gerstu áskrifandi að fréttabréfinu okkar"
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
